Module: Gravtastic::ClassMethods
- Defined in:
- lib/gravtastic.rb
Instance Attribute Summary collapse
-
#gravatar_defaults ⇒ Object
Returns the value of attribute gravatar_defaults.
-
#gravatar_source ⇒ Object
Returns the value of attribute gravatar_source.
Instance Method Summary collapse
-
#gravatar_abbreviations ⇒ Object
Gravtastic abbreviates certain params so that it produces the smallest possible URL.
Instance Attribute Details
#gravatar_defaults ⇒ Object
Returns the value of attribute gravatar_defaults.
60 61 62 |
# File 'lib/gravtastic.rb', line 60 def gravatar_defaults @gravatar_defaults end |
#gravatar_source ⇒ Object
Returns the value of attribute gravatar_source.
60 61 62 |
# File 'lib/gravtastic.rb', line 60 def gravatar_source @gravatar_source end |
Instance Method Details
#gravatar_abbreviations ⇒ Object
Gravtastic abbreviates certain params so that it produces the smallest possible URL. Every byte counts.
64 65 66 67 68 69 |
# File 'lib/gravtastic.rb', line 64 def gravatar_abbreviations { :size => 's', :default => 'd', :rating => 'r' } end |