Module: Gravtastic::StageOne

Defined in:
lib/gravtastic.rb

Overview

We include Gravtastic in multiple stages. This is mainly so that if you include Gravastic in a superclass (something like ActiveRecord::Base) then it only adds the relevant methods to the classes which actually use it.

Instance Method Summary collapse

Instance Method Details

#gravtastic(*args, &blk) ⇒ Object Also known as: gravtastic!, has_gravatar, is_gravtastic, is_gravtastic!



43
44
45
46
47
48
# File 'lib/gravtastic.rb', line 43

def gravtastic(*args, &blk)
  extend ClassMethods
  include InstanceMethods
  Gravtastic.configure(self, *args, &blk)
  self
end